==> libbluray_0.2.2.orig.tar.bz2: libbluray-0.2.2/src/libbluray/bdj/java/org/videolan/media/content/playlist/PrimaryGainControlImpl.java <==
/*
 * This file is part of libbluray
 * Copyright (C) 2010  William Hahne
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 */

package org.videolan.media.content.playlist;

import java.awt.Component;

import javax.media.GainChangeListener;

import org.bluray.media.PrimaryGainControl;

public class PrimaryGainControlImpl implements PrimaryGainControl {
    public void setMute(boolean mute)
    {
        // TODO Not implemented
    }

    public boolean getMute()
    {
        return false; // TODO Not implemented
    }

    public float setDB(float gain)
    {
        return 0;  // TODO Not implemented
    }

    public float getDB()
    {
        return 0;  // TODO Not implemented
    }

    public float setLevel(float level)
    {
        return 0;
    }

    public float getLevel()
    {
        return 0;  // TODO Not implemented
    }

    public void addGainChangeListener(GainChangeListener listener)
    {
        // TODO Not implemented
    }

    public void removeGainChangeListener(GainChangeListener listener)
    {
        // TODO Not implemented
    }

    public Component getControlComponent()
    {
        return null;
    }
}

==> libbluray-0.4.0.tar.bz2: libbluray-0.4.0/src/libbluray/bdj/java/org/videolan/media/content/playlist/PrimaryGainControlImpl.java <==
/*
 * This file is part of libbluray
 * Copyright (C) 2010  William Hahne
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 */

package org.videolan.media.content.playlist;

import java.awt.Component;

import javax.media.GainChangeListener;

import org.bluray.media.PrimaryGainControl;

public class PrimaryGainControlImpl implements PrimaryGainControl {
    public void setMute(boolean mute) {
        // TODO Not implemented
    }

    public boolean getMute() {
        return false; // TODO Not implemented
    }

    public float setDB(float gain) {
        return 0;  // TODO Not implemented
    }

    public float getDB() {
        return 0;  // TODO Not implemented
    }

    public float setLevel(float level) {
        return 0;
    }

    public float getLevel() {
        return 0;  // TODO Not implemented
    }

    public void addGainChangeListener(GainChangeListener listener) {
        // TODO Not implemented
        org.videolan.Logger.unimplemented("PrimaryGainControlImpl", "addGainChangeListener");
    }

    public void removeGainChangeListener(GainChangeListener listener) {
        // TODO Not implemented
    }

    public Component getControlComponent() {
        return null;
    }
}
